# pyconstants
This is a python package that aims to bring **real** constants to python
The project is at planning stage
The project will be released to pypi when I complete coding the `ConstInt`, `ConstStr` and `ConstFloat` classes

## Things I plan to do
1- Finish coding `ConstInt`, `ConstStr` and `ConstFloat` classes and publish the package to PyPi
Status: The metaclass is almost ready, I have to code type spesific methods now

2- Code the `ConstDict`, `ConstList`, `ConstTuple` and other mutable builtin types
Status: Not started

3- Code a `CustomConst` class, which can be used to create constants of any type
Status: Not started

4- Write a documentation at readthedocs.io
Status: Documentation is being written

5- Create a issue system that people can request some common but not builtin types to have its own class that comes with the package
Status: Not started